==> haskell-crypton-connection-0.4.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-connection
version:              0.4.3
visibility:           public
id:                   crypton-connection-0.4.3-FgkWj1luww32ENRPgwmLUE
key:                  crypton-connection-0.4.3-FgkWj1luww32ENRPgwmLUE
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connection API
description:
    Simple network library for all your connection needs.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  2e0e7e8b3dd9a1584bfd0ef5fe63dfc7
exposed:              True
exposed-modules:      Network.Connection Network.Connection.Internal
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.4.3-FgkWj1luww32ENRPgwmLUE
depends:
    base-4.17.2.1 basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7
    bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-LQsOJOeijoVKAs6avnFKjN
    crypton-x509-store-1.6.11-5O43Jdk8Sbq5IcuqKgEiEb
    crypton-x509-system-1.6.7-2giyWB0KeCe8KIMDgxn88V
    crypton-x509-validation-1.6.14-BvKcIeK7RqcCEp0GO5twqt
    data-default-0.7.1.2-95OdNmNpLKa9cNDp3ZlqO5
    network-3.1.4.0-HbZCj3UHcZsFvn6ftFrD4m
    socks-0.6.1-HePG2qNUpSR56G17s5pHRB tls-2.0.6-BmuiHslymy76gQW8YEawa2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-connection-0.4.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-connection
version:              0.4.3
visibility:           public
id:                   crypton-connection-0.4.3-9njtefs2cjdHTTbYYs7Bzn
key:                  crypton-connection-0.4.3-9njtefs2cjdHTTbYYs7Bzn
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-connection
synopsis:             Simple and easy network connection API
description:
    Simple network library for all your connection needs.

    Features: Really simple to use, SSL/TLS, SOCKS.

    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.

category:             Network
abi:                  989ca8d3bc3f2067247f9298315b704f
exposed:              True
exposed-modules:      Network.Connection Network.Connection.Internal
hidden-modules:       Network.Connection.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-connection-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-connection
hs-libraries:         HScrypton-connection-0.4.3-9njtefs2cjdHTTbYYs7Bzn
depends:
    base-4.17.2.1 basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7
    bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-G2LNxPOT7SyGlUlsjdK8wD
    crypton-x509-store-1.6.11-1hx0BcInLbFLoMkFkXMWfC
    crypton-x509-system-1.6.7-KzhlWFKMCMT2YRM65tbEdp
    crypton-x509-validation-1.6.14-EeJozhExHwK8pgteJPln9R
    data-default-0.7.1.2-GUUW0V5lisrJnDmYs4YZIH
    network-3.1.4.0-480JOeNLV9o5fbqpzcHJCB
    socks-0.6.1-3Re7CR6G9HiBzZFsTgZ25U tls-2.0.6-AbbkodQw07u3L7IwptCXQ4

haddock-interfaces:
    /usr/share/doc/haskell-crypton-connection/html/crypton-connection.haddock

haddock-html:         /usr/share/doc/haskell-crypton-connection/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
